#
# spec file for package unison
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define build_flavor %nil
%if "%build_flavor" == "doc"
%define nsuffix -doc
%else
%define nsuffix %nil
%endif

%define     pkg unison
Name:           %pkg%nsuffix
Version:        2.53.7
Release:        1.2
%{?ocaml_preserve_bytecode}
Summary:        File synchronization tool
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
BuildRoot:      %_tmppath/%name-%version-build
URL:            https://github.com/bcpierce00/unison
Source0:        %pkg-%version.tar.xz
Source1:        %pkg.desktop
BuildRequires:  ocaml(ocaml_base_version) >= 4.08
BuildRequires:  ocaml-rpm-macros >= 20231101
%if "%build_flavor" == "doc"
BuildRequires:  hevea
BuildRequires:  lynx
BuildRequires:  texlive-collection-latex
BuildRequires:  texlive-metafont
%else
BuildRequires:  ocamlfind(lablgtk3)
BuildRequires:  pkgconfig(ncursesw)
%if 0%{?suse_version} > 0
BuildRequires:  update-desktop-files
%endif
%endif

%description
Graphical userinterface for Unison.

Unison is a file synchronization tool for Unix and Windows. It allows
two replicas of a collection of files and directories to be stored on
different hosts (or different disks on the same host), modified
separately, then brought up to date by propagating the changes in each
replica to the other.

%package text
Summary:        File synchronization tool
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other

%description text
Text based userinterface for Unison.

Unison is a file synchronization tool for Unix and Windows. It allows
two replicas of a collection of files and directories to be stored on
different hosts (or different disks on the same host), modified
separately, then brought up to date by propagating the changes in each
replica to the other.

%prep
%autosetup -p1 -n %pkg-%version

%build
%if "%build_flavor" == "doc"
%make_build docs
%else
%make_build PREFIX=%_prefix
%endif

%install
%if "%build_flavor" == "doc"
echo '%%dir %_defaultdocdir/%pkg' > files
for ext in html pdf
do
  test -f doc/unison-manual.$ext || continue
  mkdir -vp %buildroot%_defaultdocdir/%pkg
  cp doc/unison-manual.$ext %buildroot%_defaultdocdir/%pkg
  echo "%%doc %_defaultdocdir/%pkg/unison-manual.$ext" >> files
done
%else
# The presence of _defaultlicensedir is no inidicator for a usable %%license macro
# If it is defined, but rpm is still too old, it will default to the last License: line.
if bash -x -c 'read a b c < <(rpm --version)
set -- ${c//./ }
test $1 -lt 4 && exit 1
if test $1 -eq 4 && test $2 -lt 14
then
	exit 1
fi
exit 0'
then
	echo '%%license src/COPYING' > files
else
	echo '%%doc src/COPYING' > files
fi
%make_install PREFIX=%_prefix

mv %buildroot%_bindir/%name %buildroot%_bindir/%name-text
mv %buildroot%_bindir/%name-gui %buildroot%_bindir/%name
install -m 644 -D icons/U.svg %buildroot%_datadir/pixmaps/%name.svg
%if %{defined suse_update_desktop_file}
%suse_update_desktop_file -i %name Utility SyncUtility
%else
install -m 644 -D %{SOURCE1} %buildroot/%_datadir/applications/%name.desktop
%endif
%endif

%files -f files
%defattr(-,root,root,-)
%if "%build_flavor" == ""
%_datadir/applications/*
%_datadir/pixmaps/*
%_bindir/%name
%_bindir/%name-fsmonitor
%_mandir/man1/*

%files text
%defattr(-,root,root,-)
%_bindir/%name-text
%endif

%changelog
* Mon Jan 20 2025 Yunus Acar <yunus.acar@suse.com>
- Update to verison 2.53.7
  * Time remaining, when over 24h, shown as days and HMS instead of
    just HMS.
  * Stop using deprecated [GdkPixbuf.from_xpm_data] (avoids problems
    with some versions of gdkpixbuf). Attempt to avoid soundness
    issues with lablgtk while doing so.
  * Deprecation warning: support for external rsync will be removed
* Tue May  7 2024 ohering@suse.de
- Update to version 2.53.5
  * Various minor bugfixes.
  * Recovery from errors during repeat mode (enabled in 2.53.1)
    is disabled for time being.
* Tue Feb 20 2024 ohering@suse.de
- Update to version 2.53.4
  * Preferences "force", "prefer" and related "partial" preferences now
    work slightly differently with values "newer" and "older". Previously,
    if mtimes in both replicas were equal then always the second root
    propagated to the first root (possibly reverting user changes). It
    is now made explicit that "newer" and "older" only work when mtimes
    are different.
  * Bugfixes, minor improvements, cleanups.
* Fri Jul  7 2023 ohering@suse.de
- Provide a docs package with man, html and PDF files.
* Fri May  5 2023 ohering@suse.de
- Update to version 2.53.3
  * Bugfixes, minor improvements, cleanups.
* Sun Mar 19 2023 ohering@suse.de
- Update to version 2.53.2
  * Repeat mode is more fault tolerant, recovering after temporary
    errors.
  * Preferences "force", "prefer" and related no longer require
    specifying the full root.
  * Improve stopping of update propagation.
  * Add graceful stop in repeat mode - SIGUSR2.
  * Add watch+seconds to 'repeat' preference.
* Sun Jan  1 2023 olaf@aepfle.de
- Update to version 2.53.0
  * Build with GTK3
* Sun May  8 2022 olaf@aepfle.de
- Update to version 2.52.1
  * Remove rsh:// URI scheme
  * Significant bugfixes and minor improvements
* Mon Apr  4 2022 olaf@aepfle.de
- Update to version 2.52.0
  * wireprotocol is now independent from OCaml version
  * see included changelog for details
- Build with dune
- Provide unison-text package
* Thu Jun 24 2021 olaf@aepfle.de
- Update to version 2.51.4
  * Working files are stored in the unison directory (typically ~/.unison) rather than $HOME.
  * see included changelog for details
* Fri Apr  9 2021 olaf@aepfle.de
- Update to version 2.51.4_rc2
  remove Compatibility-with-OCaml-4.08.patch
  remove Compile-without-unsafe-string.patch
  remove Fix-for-lablgtk-2.18.6.patch
  remove Fix-warnings-raised-by-OCaml-4.08.1.patch
- Remove ocaml_native_compiler conditional
  build native target unconditionally
* Sat Feb 29 2020 olaf@aepfle.de
- Update to v2.51.2, via _service file
- add Fix-warnings-raised-by-OCaml-4.08.1.patch
- add Compile-without-unsafe-string.patch
- update Compatibility-with-OCaml-4.08.patch
- update Fix-for-lablgtk-2.18.6.patch
* Wed Nov 13 2019 olaf@aepfle.de
- Update to v2.48v4, via _service file
- Add Compatibility-with-OCaml-4.08.patch
- Add Fix-for-lablgtk-2.18.6.patch
- Require lablgtk2 > 2.18.5
* Fri Nov  1 2019 olaf@aepfle.de
- Require lablgtk2 < 2.18.8
* Mon Nov 13 2017 okurz@suse.com
- Update to 2.48.4
  * Fix build for OCaml 4.03
    (and add Makefile improvements for exporting under git)
  * Better reporting for OCaml compiler version mismatch
- drop patch unison-ocaml-4.03.patch: Change included in upstream sources
* Mon Jul 17 2017 olaf@aepfle.de
- Wrap specfile conditionals to fix quilt setup
* Mon May 23 2016 olaf@aepfle.de
- Require ocaml >= 4.0.3 due to its API change in Unix.symlink
  unison-ocaml-4.03.patch
* Sat Oct 10 2015 olaf@aepfle.de
- Replace BuildRequires lablgtk2-devel with ocaml-lablgtk2-devel
* Fri Oct  9 2015 tilman.vogel@web.de
- include unison-fsmonitor binary in package
* Sat Feb 21 2015 oliver@getspam.de
- Update to 2.48.3:
  * Uprintf module replaced with functionality from the standard
    library (doesn't work with ocaml4.02, caused crash)
  * many file system monitoring improvements
  * some minor changes (maxsizethreshold option and a
    copyonconflict preference added)
- removed build-fix-EG11.1.patch: was only applied for os 11.1
  which is not supported anymore
* Wed Jan 16 2013 ohering@suse.de
- disable strip and /usr/lib/rpm/find-debuginfo.sh for non-opt builds
  it destroys bytecode binaries
* Mon Jan 14 2013 saschpe@suse.de
- Update to version 2.40.102:
  + Upstream provides no changelog
- Uppercase name and a comment in unison.desktop
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Jun  6 2011 mhopf@novell.com
- Make unison build on Evergreen 11.1.
* Fri Apr 29 2011 mhopf@novell.com
- Update to 2.40.63:
  * Include makefile patch
  * Make unison compile with ocaml 3.12
  * Fix incompatibility with OpenSSH 5.6
* Thu Mar 31 2011 saschpe@suse.de
- Spec file cleanup
  * Removed authors from description
  * Removed ctags dependency
* Sat Jan 29 2011 poletti.marco@gmail.com
- Update to version 2.40.61:
  * Add "BelowPath" patterns
  * Other fixes and improvements
- Update to version 2.40.1:
  * Unicode support
  * Partial transfer of directories
  * Experimental prococol for asyncronous file tranfers, hiding latency
  * Improve the performance of the rsync protocol
  * Many (!) other improvements and fixes
* Thu Oct  7 2010 aj@suse.de
- Fix build with ocaml 3.12 (patch unison-ocaml.patch).
* Wed Dec 16 2009 mhopf@novell.com
- Update to latest stable version 2.32.52
  * If Unison is interrupted during a directory transfer, it will now leave
    the partially transferred directory intact in a temporary location
  * Added experimental support for invoking an external file transfer tool for
    whole-file copies
  * Very preliminary support for triggering Unison from an external
    filesystem-watching utility.
  * Ignore one hour differences when deciding whether a file may have been
    updated (ignore daylight saving time changes under Windows)
  * Fixed slow performances when transferring a file using our rsync
    implementation from a 64-bit architecture to a 32-bit architecture
  * Case sensitivity information put in the archive (in a backward compatible
    way) and checked when the archive is loaded
  * Upgraded to GPL version 3
  * In repeat mode, don't save the archives when there is no update
  * Tons of bug fixes + small additions
* Fri Sep  4 2009 mhopf@novell.com
- Update to latest stable version 2.27.157
  * various small fixes.
* Mon Jun 29 2009 seife@suse.de
- Updated to latest stable version 2.27.149:
  * various small fixes all over the place
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Mon Jan 21 2008 seife@suse.de
- Updated to 2.27.57:
  * only some minor bugfixes (mistriggering assertions etc)
  * the patch vor bug 331513 is incorporated upstream
* Wed Nov 28 2007 seife@suse.de
- add an application icon for unison (bug 309880)
* Thu Oct 25 2007 seife@suse.de
- fix bug 331513 (one ":" too much in the profile)
* Sun Oct  7 2007 tsieden@suse.de
- Updated to 2.27.47:
  * Major rewrite and cleanup of the whole Mac OS X graphical user
    interface by Craig Federighi.
  * Ignore all-whitespace lines in preference files
  * Small fix to ctime (non-)handling in update detection under windows
    with fastcheck.
* Fri Aug 24 2007 tsieden@suse.de
- Updated to 2.27.29:
  * small bugfixes - mostly windows related
* Thu Aug 23 2007 tsieden@suse.de
- fix build (BuildRequires lablgtk2-devel only if suse_version >1020)
* Thu May 24 2007 ro@suse.de
- added lablgtk2-devel to buildreq
* Wed Apr 25 2007 mhopf@suse.de
- Updated to 2.27.24:
  * Backup functionality completely rewritten, removing bugs.
  * Several savety improvements: mountpoint checks, big deletes, missing
    symlink destinations
  * New forcepartial and preferpartial preferences
  * Improved debugging
  * Merge functionality partially rewritten
  * Reversed diff arguments.
  * Many bugfixes (fastcheck + daylight saving time under windows, 32/64
    bit cleanup, removing deadlocks, ...)
* Tue Apr 17 2007 seife@suse.de
- add ncurses-devel to buildrequires, to fix build on s390
* Wed Dec 13 2006 mhopf@suse.de
- added patch for no longer closing main window if subwindows open
- removed unison-gtk1 again
* Wed Dec  6 2006 seife@suse.de
- add unison-gtk1, a binary compiled against lablgtk
* Mon Sep 25 2006 mhopf@suse.de
- Update to version 2.17.1
- Completely rewritten backup function (actually working now)
- Ip V6 support
- Several bug fixes
* Thu Sep 21 2006 seife@suse.de
- switch to GTK2 / lablgtk2
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 10 2005 rommel@suse.de
- update to version 2.13.16 (includes all of our recent fixes)
- updated spec file, manual is available in html now
* Tue Mar 15 2005 ro@suse.de
- enable optimized compile on x86_64
* Tue Sep 14 2004 ro@suse.de
- fix build with ocaml-3.08 (from unison-hackers ml)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Tue Jul 22 2003 rommel@suse.de
- fixed "invalid escape sequence" error messages
- fixed %%install (not using make install anymore)
- compiling with thread support
* Tue May  6 2003 ro@suse.de
- fix tail calling syntax
* Mon Jan 27 2003 rommel@suse.de
- replaced pdf file (unreadable) with ps file
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon May 27 2002 ro@suse.de
- update to 2.9.1 makes it build with current ocaml
* Fri Sep 14 2001 grimmer@suse.de
- Update to 2.7.7, which fixes the following bugs (since
  2.7.1):
  * Fixed a silly bug that would reliably prevent the Unison
    client from starting in 2.7.4.
  * Bug fix (2.7.4): read the initial connection header one byte
    at a time, so that we don't block if the header is shorter
  than expected.
* Wed Aug 29 2001 grimmer@suse.de
- Update to 2.7.1 (see the NEWS file for changes)
- updated PDF manual to latest version
* Thu Aug 16 2001 grimmer@suse.de
- Initial package for SuSE Linux (version 2.6.59)
